package org.mmga.clubs.entities;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import java.util.Date;

@Data
@Schema(description = "基础返回值")
public class BaseResponse<T> {
    @Schema(description = "返回代码（参考HTTP响应码）", examples = {"200", "404", "500", "403"})
    private int code;
    @Schema(description = "返回信息（自定义）")
    private String msg;
    @Schema(description = "响应生成时间")
    private final Date time;
    @Schema(description = "返回数据")
    private T data;
    protected BaseResponse(int code, String msg, T data){
        this.code = code;
        this.msg = msg;
        this.data = data;
        this.time = new Date();
    }
    public static <T> BaseResponse<T> success(T data){
        return new BaseResponse<>(200, "接口执行成功", data);
    }

    public static<T> BaseResponse<T> failed(int code, String msg) {
        return new BaseResponse<>(code, msg, null);
    }
    public static<T> BaseResponse<T> failed(int code, String msg, T data) {
        return new BaseResponse<>(code, msg, data);
    }
}
