package org.mmga.clubs.service;

import lombok.SneakyThrows;
import org.mmga.clubs.dao.redis.VerifyDao;
import org.mmga.clubs.entities.verify.VerifyImgVo;
import org.mmga.clubs.entities.verify.VerifyVo;
import org.mmga.clubs.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.imageio.ImageIO;
import java.awt.*;
import java.awt.image.BufferedImage;
import java.io.ByteArrayOutputStream;
import java.util.Date;
import java.util.Random;

import static org.mmga.clubs.utils.StringUtils.generatorRandomString;

@Service
public class VerifyCodeService {
    private final VerifyDao verifyDao;

    @Autowired
    public VerifyCodeService(VerifyDao verifyDao) {
        this.verifyDao = verifyDao;
    }

    @SneakyThrows
    public VerifyImgVo generateVerifyCode() {
        int width = 100;
        int height = 40;
        BufferedImage image = new BufferedImage(width,height,BufferedImage.TYPE_INT_ARGB);
        Graphics g = image.createGraphics();
        Font font = new Font("宋体",Font.BOLD,25);
        g.setFont(font);
        StringBuilder code = new StringBuilder();
        for (int i = 0; i < 4; i++) {
            int index = new Random().nextInt(StringUtils.source.length() - 1);
            char myCode = StringUtils.source.charAt(index);
            Random random = new Random();
            g.setColor(new Color(20+random.nextInt(120),20+random.nextInt(120),20+random.nextInt(120)));
            g.drawString(myCode+"",15+i*20,20+new Random().nextInt(10));
            for (int j = 0; j < 5; j++) {
                g.drawLine(random.nextInt(width),random.nextInt(height),random.nextInt(width),random.nextInt(height));
            }
            code.append(myCode);
        }
        g.dispose();
        String s = generatorRandomString(32);
        String codeString = code.toString();
        verifyDao.save(new VerifyVo(s, codeString, new Date()));
        try(ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream()){
            ImageIO.write(image, "png", byteArrayOutputStream);
            return new VerifyImgVo(byteArrayOutputStream.toByteArray(), s);
        }
    }
    public boolean invalid(String code, String ans){
        if (code == null || ans == null){
            return true;
        }
        VerifyVo byKey = verifyDao.getByKey(code);
        if (byKey == null){
            return true;
        }
        verifyDao.delete(byKey);
        return !byKey.answer().equalsIgnoreCase(ans);
    }
}

